"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.anyMapper = void 0;
const JsonLazyRef_1 = require("../domain/JsonLazyRef");
const JsonSchema_1 = require("../domain/JsonSchema");
const JsonSchemaMapperContainer_1 = require("../registries/JsonSchemaMapperContainer");
const generics_1 = require("../utils/generics");
const ref_1 = require("../utils/ref");
function anyMapper(input, options = {}) {
    if (typeof input !== "object" || input === null) {
        return input;
    }
    if (input instanceof JsonLazyRef_1.JsonLazyRef) {
        return (0, JsonSchemaMapperContainer_1.execMapper)("lazyRef", input, options);
    }
    if (input instanceof JsonSchema_1.JsonSchema && input.get("enum") instanceof JsonSchema_1.JsonSchema) {
        const enumSchema = input.get("enum");
        return (0, ref_1.toRef)(enumSchema, enumSchema.toJSON(options), options);
    }
    if (input.$kind && input.$isJsonDocument) {
        const kind = (0, JsonSchemaMapperContainer_1.oneOfMapper)(input.$kind, "map");
        const schema = (0, JsonSchemaMapperContainer_1.execMapper)(kind, input, (0, generics_1.mapGenericsOptions)(options));
        return input.canRef ? (0, ref_1.toRef)(input, schema, options) : schema;
    }
    return (0, JsonSchemaMapperContainer_1.execMapper)("object", input, options);
}
exports.anyMapper = anyMapper;
(0, JsonSchemaMapperContainer_1.registerJsonSchemaMapper)("any", anyMapper);
//# sourceMappingURL=anyMapper.js.map