"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hidden = void 0;
const core_1 = require("@tsed/core");
/**
 * Disable documentation for the class and his endpoint.
 *
 * ````typescript
 * @Controller('/')
 * export class Ctrl {
 *
 *   @Get('/')
 *   @Hidden()
 *   hiddenRoute(){
 *
 *   }
 * }
 *
 * @Controller('/')
 * @Hidden()
 * export class Ctrl {
 *   @Get('/')
 *   hiddenRoute() {
 *
 *   }
 *   @Get('/2')
 *   hiddenRoute2() {
 *
 *   }
 * }
 * ```
 *
 * @decorator
 * @ignore
 */
function Hidden() {
    return (0, core_1.StoreSet)("hidden", true);
}
exports.Hidden = Hidden;
//# sourceMappingURL=hidden.js.map