"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Name = void 0;
const core_1 = require("@tsed/core");
const jsonEntityFn_1 = require("../common/jsonEntityFn");
/**
 * Add a name metadata on the decorated element.
 *
 * ## Examples
 * ### On parameters
 *
 * ```typescript
 * async myMethod(@Name("nameOf") @PathParams("id") id: string): Promise<Model>  {
 *
 * }
 * ```
 *
 * ### On parameters
 *
 * ```typescript
 * @Name("AliasName")
 * @Controller("/")
 * class ModelCtrl {
 *
 * }
 * ```
 *
 * @param name
 * @decorator
 * @validation
 * @swagger
 * @schema
 * @input
 * @classDecorator
 * @operation
 */
function Name(name) {
    return (0, jsonEntityFn_1.JsonEntityFn)((store, args) => {
        switch ((0, core_1.decoratorTypeOf)(args)) {
            case core_1.DecoratorTypes.CLASS:
                store.schema.name(name);
                break;
            case core_1.DecoratorTypes.PARAM:
                store.parameter.name(name);
                break;
            default:
                store.parent.schema.addAlias(args[1], name);
        }
    });
}
exports.Name = Name;
//# sourceMappingURL=name.js.map