"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Produces = void 0;
const core_1 = require("@tsed/core");
const jsonEntityFn_1 = require("../common/jsonEntityFn");
/**
 * Add produces metadata on the decorated element.
 *
 * ## Examples
 * ### On method
 *
 * ```typescript
 * class Model {
 *    @Produces("text/html")
 *    id: string;
 * }
 * ```
 *
 * ::: warning
 * For openspec v3 prefer `@Returns().ContentType()` usage (see @@Returns@@).
 * :::
 *
 * @param produces
 * @decorator
 * @swagger
 * @methodDecorator
 * @classDecorator
 * @operation
 * @response
 */
function Produces(...produces) {
    return (0, jsonEntityFn_1.JsonEntityFn)((store, args) => {
        switch (store.decoratorType) {
            case core_1.DecoratorTypes.METHOD:
                store.operation.produces(produces);
                break;
            case core_1.DecoratorTypes.CLASS:
                (0, core_1.decorateMethodsOf)(args[0], Produces(...produces));
                break;
            default:
                throw new core_1.UnsupportedDecoratorType(Produces, args);
        }
    });
}
exports.Produces = Produces;
//# sourceMappingURL=produces.js.map